@@ -1,7 +1,7 @@
 package Getopt::Long::Util;
 
-our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.84'; # VERSION
+our $DATE = '2016-10-21'; # DATE
+our $VERSION = '0.85'; # VERSION
 
 use 5.010001;
 use strict;
@@ -130,7 +130,7 @@ $SPEC{humanize_getopt_long_opt_spec} = {
     v => 1.1,
     description => <<'_',
 
-Convert `Getopt::Long` option specification like `help|h|?` or `--foo=s` or
+Convert <pm:Getopt::Long> option specification like `help|h|?` or `--foo=s` or
 `debug!` into, respectively, `--help, -h, -?` or `--foo=s` or `--(no)debug`.
 Will die if can't parse the string. The output is suitable for including in
 help/usage text.
@@ -229,6 +229,7 @@ sub detect_getopt_long_script {
 
     my $yesno = 0;
     my $reason = "";
+    my %extrameta;
 
     my $str = $args{string};
   DETECT:
@@ -273,14 +274,15 @@ sub detect_getopt_long_script {
             $reason = "Does not have 'perl' in the shebang line";
             last;
         }
-        if ($str =~ /^\s*(use|require)\s+Getopt::Long(\s|;)/m) {
+        if ($str =~ /^\s*(use|require)\s+(Getopt::Long(?:::Complete)?)(\s|;)/m) {
             $yesno = 1;
+            $extrameta{'func.module'} = $2;
             last DETECT;
         }
-        $reason = "Can't find any statement requiring Getopt::Long module";
+        $reason = "Can't find any statement requiring Getopt::Long(?::Complete)? module";
     } # DETECT
 
-    [200, "OK", $yesno, {"func.reason"=>$reason}];
+    [200, "OK", $yesno, {"func.reason"=>$reason, %extrameta}];
 }
 
 # ABSTRACT: Utilities for Getopt::Long
@@ -297,19 +299,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.84 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-01-08.
-
-=head1 SEE ALSO
-
-L<Getopt::Long>
-
-L<Getopt::Long::Spec>, which can also parse Getopt::Long spec into hash as well
-as transform back the hash to Getopt::Long spec. OO interface. I should've found
-this module first before writing my own C<parse_getopt_long_opt_spec()>. But at
-least currently C<parse_getopt_long_opt_spec()> is at least about 30-100+%
-faster than Getopt::Long::Spec::Parser, has a much simpler implementation (a
-single regex match), and can handle valid Getopt::Long specs that
-Getopt::Long::Spec::Parser fails to parse, e.g. C<foo|f=s@>.
+This document describes version 0.85 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2016-10-21.
 
 =head1 FUNCTIONS
 
@@ -372,7 +362,7 @@ Return value:  (any)
 
 =head2 humanize_getopt_long_opt_spec($optspec) -> str
 
-Convert C<Getopt::Long> option specification like C<help|h|?> or C<--foo=s> or
+Convert L<Getopt::Long> option specification like C<help|h|?> or C<--foo=s> or
 C<debug!> into, respectively, C<--help, -h, -?> or C<--foo=s> or C<--(no)debug>.
 Will die if can't parse the string. The output is suitable for including in
 help/usage text.
@@ -383,7 +373,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<optspec>* => I<str>
+=item * B<$optspec>* => I<str>
 
 =back
 
@@ -400,15 +390,11 @@ Examples:
 
 =item * Example #1:
 
- parse_getopt_long_opt_spec( optspec => "help|h|?"); # -> { dash_prefix => "", opts => ["help", "h", "?"] }
+ parse_getopt_long_opt_spec("help|h|?"); # -> { dash_prefix => "", opts => ["help", "h", "?"] }
 
 =item * Example #2:
 
- parse_getopt_long_opt_spec( optspec => "--foo=s");
-
-Result:
-
- { dash_prefix => "--", desttype => "", opts => ["foo"], type => "s" }
+ parse_getopt_long_opt_spec("--foo=s"); # -> { dash_prefix => "--", desttype => "", opts => ["foo"], type => "s" }
 
 =back
 
@@ -444,7 +430,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<optspec>* => I<str>
+=item * B<$optspec>* => I<str>
 
 =back
 
@@ -466,6 +452,18 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Getopt::Long>
+
+L<Getopt::Long::Spec>, which can also parse Getopt::Long spec into hash as well
+as transform back the hash to Getopt::Long spec. OO interface. I should've found
+this module first before writing my own C<parse_getopt_long_opt_spec()>. But at
+least currently C<parse_getopt_long_opt_spec()> is at least about 30-100+%
+faster than Getopt::Long::Spec::Parser, has a much simpler implementation (a
+single regex match), and can handle valid Getopt::Long specs that
+Getopt::Long::Spec::Parser fails to parse, e.g. C<foo|f=s@>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
